import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutter_widget_from_html_core/flutter_widget_from_html_core.dart';
import 'package:get/get.dart';
import 'package:wow_views/common/color.dart';
import 'package:wow_views/interfaces/interface_action.dart';
import 'package:wowit/common.dart';
import 'package:wowit/message.dart';
import 'package:wowit/methods.dart';

class ViewHTML {
  Widget getMainView(Map<String, dynamic> data, String tableName) {
    var dataReponse = Methods.getList(data['data'], tableName);
    IActionEvent iAction = data['ActionEvent'] as IActionEvent;
    if (dataReponse.isNotEmpty) {
      String keyTitle = Methods.getString(dataReponse[0], 'keyTitle');
      Color color = Methods.getColor(dataReponse[0], 'textColor',
          defaultValue: Common.colorAppbar);
      double fontSize = Methods.getDouble(dataReponse[0], 'fontSize');
      String htmlXemThem = Methods.getString(dataReponse[0], 'htmlXemThem');
      String html = Methods.getString(dataReponse[0], 'htmThongtin');
      bool anHtml = Methods.getBool(data, 'anHtml');
      return ThongTinHTML(
        color: color,
        fontSize: fontSize,
        html: html,
        htmlXemThem: htmlXemThem,
        keyTitle: keyTitle,
        iAction: iAction,
        anHtml: anHtml,
      );
    } else {
      return Container();
    }
  }
}

class ThongTinHTML extends StatefulWidget {
  final String keyTitle;
  final Color color;
  final double fontSize;
  final String html;
  final String htmlXemThem;
  final IActionEvent iAction;
  final bool anHtml;

  const ThongTinHTML({
    super.key,
    required this.keyTitle,
    required this.color,
    required this.fontSize,
    required this.html,
    required this.htmlXemThem,
    required this.iAction,
    required this.anHtml,
  });

  @override
  State<ThongTinHTML> createState() => _ThongTinHTMLState();
}

class _ThongTinHTMLState extends State<ThongTinHTML> {
  bool isXemThem = false;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        if (widget.keyTitle.isNotEmpty) ...[
          Text(
            Message.getMessage(widget.keyTitle),
            style: TextStyle(
              color: widget.color,
              fontWeight: FontWeight.bold,
              fontSize: widget.fontSize > 0 ? widget.fontSize : 18,
            ),
          ),
          const SizedBox(
            height: 16,
          )
        ],
        if (widget.anHtml) ...[
          Center(
            child: Image.asset(
              'assets/images/emptyFolder.png',
              height: 100,
              width: 100,
            ),
          )
        ] else ...[
          _html(widget.html),
          if (widget.htmlXemThem.isNotEmpty) ...[
            if (isXemThem) ...[_html(widget.htmlXemThem)],
            const SizedBox(
              height: 8,
            ),
            Container(
              width: Get.width,
              alignment: Alignment.center,
              child: InkWell(
                onTap: () {
                  setState(() {
                    isXemThem = !isXemThem;
                  });
                },
                child: Text(
                    Message.getMessage(
                        isXemThem ? 'BUTTON_THUGON' : 'BUTTON_XEMTATCA'),
                    textAlign: TextAlign.center,
                    style: const TextStyle(
                      color: Bds8xColor.blue367E,
                    )),
              ),
            ),
          ]
        ]
      ],
    );
  }

  Widget _html(String html) {
    return HtmlWidget(
      html,
      textStyle: const TextStyle(
        fontSize: 14,
      ),
      onTapUrl: (value) {
        if (kDebugMode) {
          print('onTap Link: $value');
        }
        var dataSplit = value.split('?');

        if (dataSplit.length >= 2) {
          Map valueMap = {};
          var data = dataSplit[dataSplit.length - 1].split('&');
          for (var item in data) {
            var listItem = item.split('=');
            if (listItem.length == 2) {
              valueMap[listItem[0]] = listItem[1];
            }
          }
          if (valueMap.isNotEmpty) {
            widget.iAction.goToViewById(Methods.getInt(valueMap, 'idView'),
                Methods.getInt(valueMap, 'id'));
            return true;
          }
        }
        return false;
      },
    );
  }
}
